mercurial/wireprotov2peer.py
branchstable
changeset 40723 94b0d0f996e1
parent 40139 17223d8e7d75
child 40724 15a643304728
--- a/mercurial/wireprotov2peer.py	Tue Nov 20 18:47:19 2018 -0500
+++ b/mercurial/wireprotov2peer.py	Wed Nov 28 10:37:43 2018 -0800
@@ -458,7 +458,10 @@
         self._redirects.append((requestid, res))
 
     def _processredirect(self, rid, res):
-        """Called to continue processing a response from a redirect."""
+        """Called to continue processing a response from a redirect.
+
+        Returns a bool indicating if the redirect is still serviceable.
+        """
         response = self._responses[rid]
 
         try:
@@ -470,7 +473,7 @@
                 response._oninputcomplete()
 
             if rid not in self._futures:
-                return
+                return bool(data)
 
             if response.command not in COMMAND_DECODERS:
                 self._futures[rid].set_result(response.objects())